aboutsummaryrefslogtreecommitdiff
path: root/sound/musicplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'sound/musicplugin.h')
-rw-r--r--sound/musicplugin.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/sound/musicplugin.h b/sound/musicplugin.h
index bdbd07ad31..cd49942b83 100644
--- a/sound/musicplugin.h
+++ b/sound/musicplugin.h
@@ -100,9 +100,9 @@ public:
* @param mixer Pointer to the global Mixer object
* @param mididriver Pointer to a pointer which the MusicPluginObject sets
* to the newly create MidiDriver, or 0 in case of an error
* @return a PluginError describing the error which occurred, or kNoError
*/
- virtual PluginError createInstance(Audio::Mixer *mixer, MidiDriver **mididriver) const = 0;
+ virtual Common::Error createInstance(Audio::Mixer *mixer, MidiDriver **mididriver) const = 0;
};
@@ -100,9 +100,9 @@ public:
* @param mididriver Pointer to a pointer which the MusicPluginObject sets
* to the newly create MidiDriver, or 0 in case of an error
- * @return a PluginError describing the error which occurred, or kNoError
+ * @return a Common::Error describing the error which occurred, or kNoError
*/